@@ -3,7 +3,7 @@ from enum import Enum
 from dotenv import load_dotenv
 load_dotenv()
 
-MODELIFY_API_URL = "http://localhost:8000/v1"
+MODELIFY_API_URL = "https://api.modelify.ai/v1"
 MODELIFY_TOKEN_VALIDATION_URL = MODELIFY_API_URL + "/registry/me"
 MODELIFY_INFO_URL = MODELIFY_API_URL + "/info"
 MODELIFY_DEPLOY_URL =  MODELIFY_API_URL + "/registry/deploy"
